@@ -7,7 +7,7 @@
 
 #define VER1 "1"
 #define VER2 "0"
-#define VER3 "2"
+#define VER3 "5"
 
 static void help(void)
 {
@@ -113,6 +113,8 @@ int hook_detect_host()
 /* Runs when things should be detected for the target system */
 int hook_detect_target()
 {
+	char *tmp;
+
 	put("/local/version", VER1 "." VER2 "." VER3);
 	put("/local/version/1", VER1);
 	put("/local/version/2", VER2);
@@ -151,6 +153,16 @@ int hook_detect_target()
 		require("cc/soname", 0, 0);
 		require("cc/rdynamic", 0, 0);
 		require("cc/pragma_message",  0, 0);
+		require("cc/disable_c23/cflags",  0, 1);
+
+	/* set cflags for C99 - have to disable C23 because it is incompatible */
+	tmp = get("cc/disable_c23/cflags");
+	if ((tmp != NULL) && (*tmp != '\0')) {
+		append("/target/cc/cflags", " ");
+		append("/target/cc/cflags", tmp);
+	}
+
+
 		require("sys/types/size_t/includes", 0, 0);
 		require("libs/fs/realpath/presents", 0, 0);
 		require("libs/env/putenv", 0, 1);
